@@ -82,7 +82,7 @@ class BaseStatPlot(Helpers):
                  x_label='',
                  y_label='',
                  print_x_labels=True,
-                 x_manual_tick_labels=None,
+                 Groups_Name=None,
                  Posthoc_Matrix=[],
                  Posthoc_Tests_Name='',
                  colormap=None,
@@ -125,7 +125,7 @@ class BaseStatPlot(Helpers):
         self.p_printed = self.make_p_value_printed(self.p)
         self.stars_printed = self.make_stars_printed(self.make_stars(self.p))
 
-        self.x_manual_tick_labels = x_manual_tick_labels if x_manual_tick_labels is not None else [
+        self.groups_name = Groups_Name if Groups_Name is not None else [
             '']
 
         if colormap is not None and colormap != ['']:
@@ -168,9 +168,9 @@ class BaseStatPlot(Helpers):
                        linewidth=2,
                        widths=0.85,
                        vert=True,
-                       showmeans=True,
-                       showmedians=True,
-                       showextrema=True,
+                       showmeans=False,
+                       showmedians=False,
+                       showextrema=False,
                        points=200,
                        bw_method=0.5):
 
@@ -341,7 +341,7 @@ class BaseStatPlot(Helpers):
                     marker='o',
                     markersize=8,
                     linewidth=1.2,
-                    zorder=1):
+                    zorder=2):
         # Generate x jitter pool.
         spread_pool = []  # storing x positions of data points
         for i, data in enumerate(self.data_groups):
@@ -358,15 +358,15 @@ class BaseStatPlot(Helpers):
                     linewidth=linewidth*self.figure_scale_factor,
                     # Connect the data points if desired.
                     linestyle='-' if self.dependent else '',
-                    zorder=zorder)
+                    zorder=zorder-1)
 
     def add_swarm(self, ax,
-                  color='grey',
+                  color='dimgrey',
                   alpha=1,
                   marker='o',
                   markersize=8,
                   linewidth=1.4,
-                  zorder=1):
+                  zorder=2):
         """
         Add a swarmplot (scatter-like plot with non-overlapping points)
         to the provided Axes. Automatically reduce point size if overcrowded.
@@ -408,12 +408,12 @@ class BaseStatPlot(Helpers):
             for i, data in enumerate(self.transpose(self.data_groups)):
                 ax.plot(range(len(data)), data,
                         color=color,
-                        alpha=alpha * 0.7,
+                        alpha=alpha * 0.25,
                         linewidth=linewidth * self.figure_scale_factor,
                         zorder=zorder - 1)
 
     def add_errorbar_sd(self, ax, x,
-                        capsize=8,
+                        capsize=4,
                         ecolor='r',
                         linewidth=2,
                         zorder=3):
@@ -424,10 +424,12 @@ class BaseStatPlot(Helpers):
                     capsize=capsize*self.figure_scale_factor,
                     ecolor=ecolor,
                     linewidth=linewidth*self.figure_scale_factor,
+                    elinewidth=linewidth*self.figure_scale_factor,
+                    capthick=linewidth*self.figure_scale_factor,
                     zorder=zorder)
 
     def add_errorbar_sem(self, ax, x,
-                         capsize=8,
+                         capsize=4,
                          ecolor='r',
                          linewidth=2,
                          zorder=3):
@@ -439,35 +441,40 @@ class BaseStatPlot(Helpers):
                     ecolor=ecolor,
                     linewidth=linewidth*self.figure_scale_factor,
                     elinewidth=linewidth*self.figure_scale_factor,
+                    capthick=linewidth*self.figure_scale_factor,
                     zorder=zorder)
 
     def add_mean_marker(self, ax, x,
                         marker='_',
                         markerfacecolor='#00000000',
                         markeredgecolor='r',
-                        markersize=16,
-                        markeredgewidth=1):
+                        markersize=20,
+                        linewidth=2,
+                        zorder=3):
         # Overlay mean marker
         ax.plot(x, self.mean[x],
                 marker=marker,
                 markerfacecolor=markerfacecolor,
                 markeredgecolor=markeredgecolor,
                 markersize=markersize*self.figure_scale_factor,
-                markeredgewidth=markeredgewidth*self.figure_scale_factor)
+                markeredgewidth=linewidth*self.figure_scale_factor,
+                zorder=zorder)
 
     def add_median_marker(self, ax, x,
-                          marker='x',
-                          markerfacecolor='#00000000',
+                          marker='o',
+                          markerfacecolor="#FFFFFFFF",
                           markeredgecolor='r',
-                          markersize=10,
-                          markeredgewidth=1):
+                          markersize=6,
+                          linewidth=2,
+                          zorder=4):
         # Overlay median marker
         ax.plot(x, self.median[x],
                 marker=marker,
                 markerfacecolor=markerfacecolor,
                 markeredgecolor=markeredgecolor,
                 markersize=markersize*self.figure_scale_factor,
-                markeredgewidth=markeredgewidth*self.figure_scale_factor)
+                markeredgewidth=linewidth*self.figure_scale_factor,
+                zorder=zorder)
 
     def add_significance_bars(self, ax,
                               linewidth=2,
@@ -569,10 +576,10 @@ class BaseStatPlot(Helpers):
         # Set x ticks and labels
         if self.print_x_labels:
             plt.subplots_adjust(bottom=0.11)
-            if self.x_manual_tick_labels != ['']:
+            if self.groups_name != ['']:
                 ax.set_xticks(range(self.n_groups))
-                ax.set_xticklabels([self.x_manual_tick_labels[i % len(self.x_manual_tick_labels)]
-                                    for i in range(self.n_groups)])
+                ax.set_xticklabels([self.groups_name[i % len(self.groups_name)]
+                                    for i in range(self.n_groups)], fontweight='regular', fontsize=8*self.figure_scale_factor)
             else:
                 ax.set_xticks(range(self.n_groups))
                 ax.set_xticklabels(['Group {}'.format(i + 1)
@@ -628,19 +635,18 @@ class BaseStatPlot(Helpers):
 
 class BarStatPlot(BaseStatPlot):
 
-    def plot(self):
+    def plot(self, linewidth=1.8):
         fig, ax = self.setup_figure()
-        linewidth = 2
-
+        
         for x in range(len(self.data_groups)):
 
             # Create a bar for given group.
-            self.add_barplot(ax, x)
+            self.add_barplot(ax, x, linewidth=linewidth)
 
             # Overlay errbars, and markers.
-            self.add_median_marker(ax, x)
-            self.add_mean_marker(ax, x)
-            self.add_errorbar_sd(ax, x)
+            self.add_median_marker(ax, x, linewidth=linewidth)
+            self.add_mean_marker(ax, x, linewidth=linewidth)
+            self.add_errorbar_sd(ax, x, linewidth=linewidth)
 
         self.add_swarm(ax)
         self.add_significance_bars(ax, linewidth)
@@ -661,9 +667,8 @@ class ViolinStatPlot(BaseStatPlot):
         https://seaborn.pydata.org/archive/0.11/generated/seaborn.violinplot.html
     '''
 
-    def plot(self):
+    def plot(self, linewidth=1.8):
         fig, ax = self.setup_figure()
-        linewidth = 2
 
         for x in range(len(self.data_groups)):
 
@@ -671,21 +676,23 @@ class ViolinStatPlot(BaseStatPlot):
             self.add_violinplot(ax, x)
 
             # Overlay errbars and markers.
-            self.add_median_marker(ax, x)
-            self.add_mean_marker(ax, x)
-            # self.add_errorbar_sd(ax, x)
+            self.add_median_marker(ax, x, linewidth=linewidth)
+            self.add_mean_marker(ax, x, linewidth=linewidth)
+            self.add_errorbar_sd(ax, x, linewidth=linewidth)
 
         self.add_swarm(ax)
         self.add_significance_bars(ax, linewidth)
         self.add_titles_and_labels(fig, ax)
         self.axes_formatting(ax, linewidth)
 
+        xmin, xmax = ax.get_xlim()
+        ax.set_xlim(xmin - 0.3, xmax + 0.3)
+
 
 class BoxStatPlot(BaseStatPlot):
 
-    def plot(self):
+    def plot(self, linewidth=1.8):
         fig, ax = self.setup_figure()
-        linewidth = 2
 
         self.add_boxplot(ax)
         self.add_swarm(ax)
@@ -696,16 +703,15 @@ class BoxStatPlot(BaseStatPlot):
 
 class ScatterStatPlot(BaseStatPlot):
 
-    def plot(self):
+    def plot(self, linewidth=1.8):
         fig, ax = self.setup_figure()
-        linewidth = 2
 
         for x in range(len(self.data_groups)):
 
             # Overlay errbars, and markers.
-            self.add_median_marker(ax, x)
-            self.add_mean_marker(ax, x)
-            self.add_errorbar_sd(ax, x)
+            self.add_median_marker(ax, x, linewidth=linewidth)
+            self.add_mean_marker(ax, x, linewidth=linewidth)
+            self.add_errorbar_sd(ax, x, linewidth=linewidth)
 
         self.add_scatter(ax)
         self.add_significance_bars(ax, linewidth)
@@ -713,21 +719,20 @@ class ScatterStatPlot(BaseStatPlot):
         self.axes_formatting(ax, linewidth)
 
         xmin, xmax = ax.get_xlim()
-        ax.set_xlim(xmin - 0.25, xmax + 0.25)
+        ax.set_xlim(xmin - 0.3, xmax + 0.3)
 
 
 class SwarmStatPlot(BaseStatPlot):
 
-    def plot(self):
+    def plot(self, linewidth=1.8):
         fig, ax = self.setup_figure()
-        linewidth = 2
 
         for x in range(len(self.data_groups)):
 
             # Overlay errbars, and markers.
-            self.add_median_marker(ax, x)
-            self.add_mean_marker(ax, x)
-            self.add_errorbar_sd(ax, x)
+            self.add_median_marker(ax, x, linewidth=linewidth)
+            self.add_mean_marker(ax, x, linewidth=linewidth)
+            self.add_errorbar_sd(ax, x, linewidth=linewidth)
 
         self.add_swarm(ax)
         self.add_significance_bars(ax, linewidth)
@@ -735,4 +740,4 @@ class SwarmStatPlot(BaseStatPlot):
         self.axes_formatting(ax, linewidth)
 
         xmin, xmax = ax.get_xlim()
-        ax.set_xlim(xmin - 0.25, xmax + 0.25)
+        ax.set_xlim(xmin - 0.3, xmax + 0.3)
